@@ -1,5 +1,6 @@
 """Admin classes for the review app."""
 from django.contrib import admin
+from django.utils.translation import ugettext_lazy as _
 
 from hvad.admin import TranslatableAdmin
 
@@ -19,8 +20,16 @@ class ReviewExtraInfoAdmin(admin.ModelAdmin):
     list_display = ['type', 'review', 'content_object']
 
 
+class ReviewCategoryChoiceAdmin(TranslatableAdmin):
+    list_display = ['ratingcategory', 'value', 'get_label']
+
+    def get_label(self, obj):
+        return obj.label
+    get_label.short_description = _('Label')
+
+
 admin.site.register(models.Rating, RatingAdmin)
 admin.site.register(models.RatingCategory, TranslatableAdmin)
 admin.site.register(models.Review, ReviewAdmin)
 admin.site.register(models.ReviewExtraInfo, ReviewExtraInfoAdmin)
-admin.site.register(models.RatingCategoryChoice, TranslatableAdmin)
+admin.site.register(models.RatingCategoryChoice, ReviewCategoryChoiceAdmin)
