@@ -29,7 +29,7 @@ def render_category_averages(obj, normalize_to=100):
         if not category_averages:
             category_averages = review_category_averages
         else:
-            for category, average in review_category_averages:
+            for category, average in review_category_averages.iteritems():
                 category_averages[category] += review_category_averages[
                     category]
     if reviews and category_averages:
